@@ -107,6 +107,8 @@ class snowflake_processor:
                 user = self.credentials.get('username'),
                 password = self.credentials.get('password'),
                 account = self.credentials.get('account'),
+                database = self.credentials.get('database'),
+                warehouse = self.credentials.get('warehouse'),
                 )
 
             self.logger.info(f'Connection to {self.credentials.get("account")} successful')
